@@ -22,6 +22,7 @@ use Carp;
 use Log::Log4perl qw(get_logger :levels);
 
 extends 'Config::Model::Backend::Any';
+with "Config::Model::Role::FileHandler";
 
 use Config::Model::Exception;
 
@@ -32,12 +33,10 @@ my $has_augeas = 1;
 eval { require Config::Augeas; };
 $has_augeas = 0 if $@;
 
-our $VERSION = '0.123';
+our $VERSION = '0.125';
 
 my $logger = get_logger('Backend::Augeas');
 
-sub suffix { return ''; }
-
 =head1 NAME
 
 Config::Model::Backend::Augeas - Read and write config data through Augeas
@@ -239,10 +238,10 @@ sub read {
         }
     }
 
-    my $cdir = $args{root} . $args{config_dir};
+    my $cdir = $self->get_tuned_config_dir(%args);
     $logger->info( "Read config data through Augeas in directory '$cdir' " . "file $args{file}" );
 
-    my $mainpath = '/files' . $args{config_dir} . $args{file};
+    my $mainpath = '/files' . $args{config_dir} . '/'. $args{file};
 
     my @result  = $self->augeas_deep_match($mainpath);
     my @cm_path = @result;
@@ -403,12 +402,12 @@ sub write {
         }
     }
 
-    my $cdir = $args{root} . $args{config_dir};
+    my $cdir = $self->get_tuned_config_dir(%args);
     get_logger("Data::Write")
         ->info( "Write config data through Augeas in directory '$cdir' " . "file $args{file}" );
 
     my $set_in     = $args{set_in} || '';
-    my $mainpath   = '/files' . $args{config_dir} . $args{file};
+    my $mainpath   = '/files' . $args{config_dir} . '/' . $args{file};
     my $augeas_obj = $self->{augeas_obj} ||= Config::Augeas->new(
         root => $args{root},
         save => $args{save} );
@@ -753,16 +752,16 @@ http://augeas.net/ : Augeas project page
 
 =item *
 
-L<Config::Model> 
+config-model wiki: L<http://github.com/dod38fr/config-model/wiki>
+
+=item *
+
+Blogs about this project: L<https://ddumont.wordpress.com/category/perl/configmodel/>
 
 =item *
 
 Augeas mailing list: http://augeas.net/developers.html
 
-=item *
-
-Config::Model mailing list : http://sourceforge.net/mail/?group_id=155650
-
 =back
 
 =head1 AUTHOR
